.. Karaage documentation master file, created by
   sphinx-quickstart on Thu Jan 16 14:28:57 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Karaage admin documentation
===========================

This is documentation for Karaage 3. For documentation for version 2.7.x of
Karaage, please see `the latest documentation
<http://karaage.readthedocs.org/en/2.7.stable/>`_.

:Date: |today|
:Version: |version|

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   getting_started
   datastores
   plugins
   cluster
   tasks
   upgrading
   ref
   changes
   glossary

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

